@@ -49,22 +49,15 @@ class EvolutionApp(Application, EmailClient):
 			self.gtkhtmlVersion = packageDb.getVersion(self.gtkhtmlPackageName)
 			print "%s version %s"%(self.gtkhtmlPackageName, self.gtkhtmlVersion)
 
-		# In theory there can be more than one main window but we don't normally care:
-		self.mainWindow = self.window("Evolution - Mail") # FIXME: make this support other components
-		self.fileMenu = self.mainWindow.menu("File")
-		self.editMenu = self.mainWindow.menu("Edit")
-		if self.evoVersion<Version([2,3,0]):
-			self.toolsMenu = self.mainWindow.menu("Tools")
-
 	def getConfigMenuItem(self):
 		"""
 		Get the menu item that triggers the Settings/Preferences dialog,
 		handling version-specific differences
 		"""
 		if self.evoVersion<Version([2,1,0]):
-			return self.toolsMenu.menuItem("Settings...")
+			return self.menu("Tools").menuItem("Settings...")
 		else:
-			return self.editMenu.menuItem("Preferences")
+			return self.menu("Edit").menuItem("Preferences")
 
 	def doPasswordDialog(self, password, rememberPassword):
 		"""
@@ -100,7 +93,7 @@ class EvolutionApp(Application, EmailClient):
 		"""
 		Open the File->Import wizard and navigate to the second page
 		"""
-		self.fileMenu.menuItem("Import...").click()
+		self.menu("File").menuItem("Import...").click()
 		importAssistant = Wizard(self.child("Evolution Import Assistant", recursive=False), "Import Assistant")
 		importAssistant.clickForward()
 		return importAssistant
@@ -158,25 +151,7 @@ class EvolutionApp(Application, EmailClient):
 		# FIXME: now view it and see if we're still alive
 		# use PrintPreview as well
 
-	def createAccount(self, account, accountName):
-		"""
-		Add a new account, running the Evolution Account Assistant, filling in
-		the values given.
-		"""
-		
-		self.getConfigMenuItem().click()
-		settingsDlg = self.child("Evolution Settings", recursive=False)
-		#pageTabs = settingsDlg.child(roleName="page tab list")
-		# page tabs don't seem to be labelled in the tree... how do we get at this?
-
-		# for now, assume Mail Accounts tab is selected..
-		# Account wizard takes a while to appear...
-		settingsDlg.child("Add").click()
-		# this one needs a watch, I guess
-
-		accountWiz = Wizard(self.child("Evolution Account Assistant", recursive=False),"Evolution Account Assistant")
-		accountWiz.clickForward()
-
+	def __doIdentityPage(self, accountWiz, account):	
 		# "Identity" page:
 		accountWiz.child(label="Full Name:").text = account.fullName
 		accountWiz.child(label="Email Address:").text = account.emailAddress
@@ -184,6 +159,7 @@ class EvolutionApp(Application, EmailClient):
 		accountWiz.child(label="Organization:").text = account.organisation
 		accountWiz.clickForward()
 
+	def __doReceivingEmailPage(self, accountWiz, account):	
 		# "Receiving Email" page:
 		accountWiz.child(label="Server Type: ").combovalue=account.getReceivingComboValue()
 
@@ -216,17 +192,21 @@ class EvolutionApp(Application, EmailClient):
 
 		accountWiz.clickForward()
 
+	def __doReceivingOptionsPage(self, accountWiz, account):	
 		# "Receiving Options" page:
 		# FIXME: implement
 		accountWiz.clickForward()
 
+	def __doSendingEmailPage(self, accountWiz, account):	
 		# "Sending Email" page:
 		# FIXME: this fails; it picks up on the "Server Type:" from the earlier page
 		# and hence can't find the value it wants in the combo.  Should use the correct page for all of this...
-		accountWiz.child(label="Server Type: ").combovalue = account.getSendingComboValue()
+		sendingEmailPage = accountWiz.currentPage()
+		sendingEmailPage.child(label="Server Type: ").combovalue = account.getSendingComboValue()
+		print sendingEmailPage
 		if isinstance(account,MixedAccount):
 			if isinstance(account.sendMethod,SMTPSettings):
-				accountWiz.child("SMTP").text = account.sendMethod.server
+				sendingEmailPage.child(label="Server:").text = account.sendMethod.server
 				# FIXME: "Server requires authentication"
 				# etc etc
 
@@ -238,24 +218,79 @@ class EvolutionApp(Application, EmailClient):
 			raise NotImplementedError
 		accountWiz.clickForward()
 
+	def __doAccountManagementPage(self, accountWiz, accountName):	
 		# "Account Management" page:
 		accountWiz.child(label="Name:").text = accountName
 		accountWiz.clickForward()
 
+	def createAccount(self, account, accountName):
+		"""
+		Add a new account, running the Evolution Account Assistant, filling in
+		the values given.
+		"""
+		
+		self.getConfigMenuItem().click()
+		settingsDlg = self.child("Evolution Settings", recursive=False)
+		#pageTabs = settingsDlg.child(roleName="page tab list")
+		# page tabs don't seem to be labelled in the tree... how do we get at this?
+
+		# for now, assume Mail Accounts tab is selected..
+		# Account wizard takes a while to appear...
+		settingsDlg.child("Add").click()
+		# this one needs a watch, I guess
+
+		accountWiz = Wizard(self.child("Evolution Account Assistant", recursive=False),"Evolution Account Assistant")
+		accountWiz.clickForward()
+
+		self.__doIdentityPage(accountWiz, account)
+		self.__doReceivingEmailPage(accountWiz, account)
+		self.__doReceivingOptionsPage(accountWiz, account)
+		self.__doSendingEmailPage(accountWiz, account)
+		self.__doAccountManagementPage(accountWiz, accountName)
+
 		# "Done" page:
 		accountWiz.child("Apply").click()
 
 		# FIXME: we should add a review stage where we check that all widgets have the correct settings.  (But why should that even be necessary? Can our framework implement that on the script's behalf? perhaps with a UITransaction class or somesuch?)
 
+	def doFirstTimeWizard(self, account, accountName, timezoneName):
+		setupWiz = Wizard(self.window('Evolution Setup Assistant'))
+		setupWiz.clickForward()
+
+		self.__doIdentityPage(setupWiz, account)
+		self.__doReceivingEmailPage(setupWiz, account)
+		self.__doReceivingOptionsPage(setupWiz, account)
+		self.__doSendingEmailPage(setupWiz, account)
+		self.__doAccountManagementPage(setupWiz, accountName)
+		
+		# Timezone page:
+		# FIXME: timezone selection doesn't yet work
+		#self.child("TimeZone Combobox").child(timezoneName).click()
+		setupWiz.clickForward()
+
+		# "Done" page:
+		setupWiz.child("Apply").click()
+		
 	def composeEmail(self):
 		"""
 		Utility function to start composing a new email.
 
 		Returns a Composer instance wrapping the new email composer window.
 		"""
-		self.fileMenu.child("Mail Message").click()
+		self.menu("File").child("Mail Message").click()
 		composer = self.window("Compose a message")
 		return Composer(composer)
+		
+	def createMeeting(self):
+		"""
+		Utility function to start creating a new meeting.
+
+		Returns a MeetingWindow instance wrapping the new meeting window.
+		"""
+		self.menu("File").child("Meeting").click()
+		meetingWin = self.dialog("Meeting - No summary")
+		return MeetingWindow(meetingWin)
+		
 
 class Composer(Window):
 	"""
@@ -353,6 +388,35 @@ class UndoRedoException(Exception):
 	def __str__(self):
 		return "Original value %s not equal to new value %s"%(originalValue, newValue)
 
+class AppointmentWindow(Window):
+	"""
+	Subclass of Window wrapping an Evolution appointment window, with utility functions
+	"""
+	def __init__(self, node):
+		Window.__init__(self, node)
+
+	def __setattr__(self, name, value):
+		if name=="summary":
+			self.tab("Appointment").child(label="Summary:").text = value
+		else:
+			# otherwise, use normal Python attribute-handling:
+			self.__dict__[name]=value
+
+class MeetingWindow(AppointmentWindow):
+	"""
+	Subclass of AppointmentWindow wrapping an Evolution meeting window, with utility functions
+	"""
+	def __init__(self, node):
+		AppointmentWindow.__init__(self, node)
+		self.invitationsTab = self.tab("Invitations")
+		self.attendeeTable = self.invitationsTab.child(roleName='table')
+		
+	def addAttendee(self, attendee, attendeeType, role, rsvp, status):
+		"""
+		Add an attendeee to this meeting.  Doesn't fully work yet.
+		"""
+		self.invitationsTab.button('Add').click()
+
 class SelectFolderDialog(Window):
 	"""
 	Subclass of Window wrapping an Evolution 'Select Folder' dialog, with
@@ -487,3 +551,38 @@ def TestFocus():
 	focus.dialog("Evolution Import Assistant")
 	click("Forward") # grrr... selects the Forward menu item, rather than the Forward button
 
+def blowAwayEvolution():
+	"""
+	Helper function for testing Evolution.
+
+	Use with caution.
+
+	This forcibly shuts down evolution, then blows away all Evolution settings.
+	(FIXME: first copy the GConf data first to ./evolution-gconf-backup.xml ???)	
+	"""
+	os.system ('evolution --force-shutdown')
+	sleep(5)
+	os.system ('gconftool-2 --recursive-unset /apps/evolution')
+
+
+def doFirstTimeWizard(account, accountName, timezoneName):
+	"""
+	Helper function for testing Evolution.
+
+	Use with caution.
+
+	This forcibly shuts down evolution, then blows away all Evolution settings.
+	(FIXME: first copy the GConf data first to ./evolution-gconf-backup.xml ???)
+
+	It then runs the first time wizard with the given settings.
+
+	Returns an EvolutionApp instance.
+	"""
+	blowAwayEvolution()
+	
+	run('evolution')
+	evo = EvolutionApp()
+	evo.doFirstTimeWizard(account, accountName, timezoneName)
+
+	return evo
+	
